#!/usr/bin/env python3
#
# GlobalChem - Plan B
#
# -------------------

class OralContraceptives(object):

    def __init__(self):

        self.name = 'oral_contraceptives'

    @staticmethod
    def get_smiles():

        smiles = {
            'desogestrel': 'CCC12CC(=C)C3C(C1CCC2(C#C)O)CCC4=CCCCC34',
            'dienogest': 'CC12CCC3=C4CCC(=O)C=C4CCC3C1CCC2(CC#N)O',
            'drospirenone': 'CC12CCC(=O)C=C1C3CC3C4C2CCC5(C4C6CC6C57CCC(=O)O7)C',
            'estradiol': 'CC12CCC3C(C1CCC2O)CCC4=C3C=CC(=C4)O',
            'estradiol valerate': 'CCCCC(=O)OC1CCC2C1(CCC3C2CCC4=C3C=CC(=C4)O)C',
            'estriol': 'CC12CCC3C(C1CC(C2O)O)CCC4=C3C=CC(=C4)O',
            'estrone': 'CC12CCC3C(C1CCC2=O)CCC4=C3C=CC(=C4)O',
            'ethinyl estradiol': 'CC12CCC3C(C1CCC2(C#C)O)CCC4=C3C=CC(=C4)O',
            'etonogestrel': 'CCC12CC(=C)C3C(C1CCC2(C#C)O)CCC4=CC(=O)CCC34',
            'levonorgestrel': 'CCC12CCC3C(C1CCC2(C#C)O)CCC4=CC(=O)CCC34',
            'mestranol': 'CC12CCC3C(C1CCC2(C#C)O)CCC4=C3C=CC(=C4)OC',
            'norelgestromin': 'CCC12CCC3C(C1CCC2(C#C)O)CCC4=CC(=NO)CCC34',
            'norethisterone': 'CC12CCC3C(C1CCC2(C#C)O)CCC4=CC(=O)CCC34',
            'norethisterone acetate': 'CC(=O)OC1(CCC2C1(CCC3C2CCC4=CC(=O)CCC34)C)C#C',
            'norethynodre': 'CC12CCC3C(C1CCC2(C#C)O)CCC4=C3CCC(=O)C4',
            'norgestimate': 'CCC12CCC3C(C1CCC2(C#C)OC(=O)C)CCC4=CC(=NO)CCC34',
            'progesterone': 'CC(=O)C1CCC2C1(CCC3C2CCC4=CC(=O)CCC34C)C',
        }

        return smiles

    @staticmethod
    def get_smarts():

        smarts = {
            'desogestrel': '[#6]-[#6]-[#6]12-[#6]-[#6](=[#6])-[#6]3-[#6](-[#6]-1-[#6]-[#6]-[#6]-2(-[#6]#[#6])-[#8])-[#6]-[#6]-[#6]1=[#6]-[#6]-[#6]-[#6]-[#6]-3-1',
            'dienogest': '[#6]-[#6]12-[#6]-[#6]-[#6]3=[#6]4-[#6]-[#6]-[#6](=[#8])-[#6]=[#6]-4-[#6]-[#6]-[#6]-3-[#6]-1-[#6]-[#6]-[#6]-2(-[#6]-[#6]#[#7])-[#8]',
            'drospirenone': '[#6]-[#6]12-[#6]-[#6]-[#6](=[#8])-[#6]=[#6]-1-[#6]1-[#6]-[#6]-1-[#6]1-[#6]-2-[#6]-[#6]-[#6]2(-[#6]-1-[#6]1-[#6]-[#6]-1-[#6]-21-[#6]-[#6]-[#6](=[#8])-[#8]-1)-[#6]',
            'estradiol': '[#6]-[#6]12-[#6]-[#6]-[#6]3-[#6](-[#6]-1-[#6]-[#6]-[#6]-2-[#8])-[#6]-[#6]-[#6]1:[#6]-3:[#6]:[#6]:[#6](:[#6]:1)-[#8]',
            'estradiol valerate': '[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]1-[#6]-[#6]-[#6]2-[#6]-1(-[#6]-[#6]-[#6]1-[#6]-2-[#6]-[#6]-[#6]2:[#6]-1:[#6]:[#6]:[#6](:[#6]:2)-[#8])-[#6]',
            'estriol': '[#6]-[#6]12-[#6]-[#6]-[#6]3-[#6](-[#6]-1-[#6]-[#6](-[#6]-2-[#8])-[#8])-[#6]-[#6]-[#6]1:[#6]-3:[#6]:[#6]:[#6](:[#6]:1)-[#8]',
            'estrone': '[#6]-[#6]12-[#6]-[#6]-[#6]3-[#6](-[#6]-1-[#6]-[#6]-[#6]-2=[#8])-[#6]-[#6]-[#6]1:[#6]-3:[#6]:[#6]:[#6](:[#6]:1)-[#8]',
            'ethinyl estradiol': '[#6]-[#6]12-[#6]-[#6]-[#6]3-[#6](-[#6]-1-[#6]-[#6]-[#6]-2(-[#6]#[#6])-[#8])-[#6]-[#6]-[#6]1:[#6]-3:[#6]:[#6]:[#6](:[#6]:1)-[#8]',
            'etonogestrel': '[#6]-[#6]-[#6]12-[#6]-[#6](=[#6])-[#6]3-[#6](-[#6]-1-[#6]-[#6]-[#6]-2(-[#6]#[#6])-[#8])-[#6]-[#6]-[#6]1=[#6]-[#6](=[#8])-[#6]-[#6]-[#6]-3-1',
            'levonorgestrel': '[#6]-[#6]-[#6]12-[#6]-[#6]-[#6]3-[#6](-[#6]-1-[#6]-[#6]-[#6]-2(-[#6]#[#6])-[#8])-[#6]-[#6]-[#6]1=[#6]-[#6](=[#8])-[#6]-[#6]-[#6]-3-1',
            'mestranol': '[#6]-[#6]12-[#6]-[#6]-[#6]3-[#6](-[#6]-1-[#6]-[#6]-[#6]-2(-[#6]#[#6])-[#8])-[#6]-[#6]-[#6]1:[#6]-3:[#6]:[#6]:[#6](:[#6]:1)-[#8]-[#6]',
            'norelgestromin': '[#6]-[#6]-[#6]12-[#6]-[#6]-[#6]3-[#6](-[#6]-1-[#6]-[#6]-[#6]-2(-[#6]#[#6])-[#8])-[#6]-[#6]-[#6]1=[#6]-[#6](=[#7]-[#8])-[#6]-[#6]-[#6]-3-1',
            'norethisterone': '[#6]-[#6]12-[#6]-[#6]-[#6]3-[#6](-[#6]-1-[#6]-[#6]-[#6]-2(-[#6]#[#6])-[#8])-[#6]-[#6]-[#6]1=[#6]-[#6](=[#8])-[#6]-[#6]-[#6]-3-1',
            'norethisterone acetate': '[#6]-[#6](=[#8])-[#8]-[#6]1(-[#6]-[#6]-[#6]2-[#6]-1(-[#6]-[#6]-[#6]1-[#6]-2-[#6]-[#6]-[#6]2=[#6]-[#6](=[#8])-[#6]-[#6]-[#6]-1-2)-[#6])-[#6]#[#6]',
            'norethynodre': '[#6]-[#6]12-[#6]-[#6]-[#6]3-[#6](-[#6]-1-[#6]-[#6]-[#6]-2(-[#6]#[#6])-[#8])-[#6]-[#6]-[#6]1=[#6]-3-[#6]-[#6]-[#6](=[#8])-[#6]-1',
            'norgestimate': '[#6]-[#6]-[#6]12-[#6]-[#6]-[#6]3-[#6](-[#6]-1-[#6]-[#6]-[#6]-2(-[#6]#[#6])-[#8]-[#6](=[#8])-[#6])-[#6]-[#6]-[#6]1=[#6]-[#6](=[#7]-[#8])-[#6]-[#6]-[#6]-3-1',
            'progesterone': '[#6]-[#6](=[#8])-[#6]1-[#6]-[#6]-[#6]2-[#6]-1(-[#6]-[#6]-[#6]1-[#6]-2-[#6]-[#6]-[#6]2=[#6]-[#6](=[#8])-[#6]-[#6]-[#6]-1-2-[#6])-[#6]',
        }

        return smarts