#!/usr/bin/env python3
#
# GlobalChem - Surfactants
#
# ------------------------

class Surfactants(object):

    def __init__(self):

        self.name = 'surfactants'

    @staticmethod
    def get_smiles():

        '''

        Missing Entries:

           'poe-10-oleyl ether': '',
           'poe-40-hydrogenated castor oil': '',
           'poe-60-hydrogenated castor oil': '',
           'linoleoyl macrogol glyceride': '',
           'oleoyl macrogol glyceride': '',
           'caprylocaproyl macrogol glyceride': '',
           'lauroyl macrogol glycerides': '',
           'stearoyl macrogol glycerides': '',
           'pegylated phospholipids': r'',

        '''

        smiles = {
            'poe-20-sorbitan monooleate': 'CCCCCCCCC=CCCCCCCCC(=O)OCCOCC(C1C(CC(O1)OCCO)OCCO)OCCO',
            'poe-20-sorbitan monolaurate': 'CCCCCCCCCCCC(=O)OCCOCC(C1C(C(CO1)OCCO)OCCO)OCCO',
            'sorbitan monooleate': 'CCCCCCCCC=CCCCCCCCC(=O)OCC(C1C(C(CO1)O)O)O',
            'sorbitan monolaurate': 'CCCCCCCCCCCC(=O)OCC(C1C(C(CO1)O)O)O',
            'sorbitan monostearate': 'CCCCCCCCCCCCCCCCCC(=O)OCC(C1C(C(CO1)O)O)O',
            'poloxamer 188': 'CCCOC(C)COCCO',
            'poloxamer 407': 'CC1CO1.C1CO1',
            'poe-35-castor oil': r'CCCCCCC(CC=CCCCCCCCOC(=O)OCCOCC(COCCOC(=O)OCCCCCCCC=CCC(CCCCCC)O)OCCOC(=O)OCCCCCCCC=CCC(CCCCCC)O)O',
            'peg-660-12-hydroxystearate': 'CCCCCCC(C)O.[CH2]CCCCCCCCCC(=O)OCCO',
            'tocopheryl-peg 1000-succinate': 'CC1=C(C(=C(C2=C1OC(CC2)(C)CCCC(C)CCCC(C)CCCC(C)C)C)OC(=O)CCC(=O)OCCO)C',
            'sucrose laurate': 'CCCCCCCCCCCC(=O)OC1(C(C(C(C(O1)CO)O)O)O)C2(C(C(C(O2)CO)O)O)CO',
            'sucrose palmitate': 'CCCCCCCCCCCCCCCC(=O)OC1(C(C(C(C(O1)CO)O)O)O)C2(C(C(C(O2)CO)O)O)CO',
            'caprylyl glucoside': r'CCCCCCCCCCOC1C(C(C(C(O1)CO)O)O)O',
            'polyetetramethyl butyl phenol ether': 'CC(C)(C)CC(C)(C)C1=CC=C(C=C1)OCCO',
            'soybean lecithin': 'CCCCCCCCCCCCCCCC(=O)OCC(COP(=O)([O-])OCC[N+](C)(C)C)OC(=O)CCCCCCCC=CCC=CCCCCC',
            'egg lecithin': 'CCCCCCCCCCCCCCCC(=O)OCC(COP(=O)([O-])OCC[N+](C)(C)C)OC(=O)CCCCCCCC=CCC=CCCCCC',
            'diolelyl phosphatidyl choline': 'CCCCCCCCC=CCCCCCCCC(=O)OCC(COP(=O)([O-])OCC[N+](C)(C)C)OC(=O)CCCCCCCC=CCCCCCCCC',
            'distearoyl phosphatidyl glycerol': 'CCCCCCCCCCCCCCCCCC(=O)OCC(COP(=O)(O)OCC(CO)O)OC(=O)CCCCCCCCCCCCCCCCC',
            'dimyristoyl phosphotidyl choline': 'CCCCCCCCCCCCCC(=O)OCC(COP(=O)([O-])OCC[N+](C)(C)C)OC(=O)CCCCCCCCCCCCC',
            'dioctyl sodium sulfosuccinate': 'CCCCCCCCOC(=O)CC(C(=O)OCCCCCCCC)S(=O)(=O)[O-].[Na+]',
            'ethanol': 'CCO',
            'benzyl alcohol': 'C1=CC=C(C=C1)CO',
            'isopropanol': 'CC(C)O',
            'phenethyl alcohol': 'C1=CC=C(C=C1)CCO',
            'propylene glycol': 'CC(CO)O',
            'glycerol': 'C(C(CO)O)O',
            'butylene glycol': 'CC(CCO)O',
            'peg 400': 'CC(C)CCCCCCCCCCCCCCC(=O)OCCO',
            'transcutol': 'CCOCCOCCO',
            'tetraglycol': 'C(COCCOCCOCCO)O',
            'n-methyl pyrrolidone': 'CN1CCCC1=O',
            '2-pyrrolidone': 'C1CC(=O)NC1',
            'sodium deoxycholate': 'CC(CCC(=O)[O-])C1CCC2C1(C(CC3C2CCC4C3(CCC(C4)O)C)O)C.[Na+]',
            'caprylic acid': 'CCCCCCCC(=O)O',
            'sodium caprylate': 'CCCCCCCC(=O)[O-].[Na+]',
            'potassium sorbate': 'CC=CC=CC(=O)[O-].[K+]'
        }

        return smiles

    @staticmethod
    def get_smarts():

        smarts = {
            'poe-20-sorbitan monooleate': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]=[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6]-[#8]-[#6]-[#6](-[#6]1-[#6](-[#6]-[#6](-[#8]-1)-[#8]-[#6]-[#6]-[#8])-[#8]-[#6]-[#6]-[#8])-[#8]-[#6]-[#6]-[#8]',
            'poe-20-sorbitan monolaurate': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6]-[#8]-[#6]-[#6](-[#6]1-[#6](-[#6](-[#6]-[#8]-1)-[#8]-[#6]-[#6]-[#8])-[#8]-[#6]-[#6]-[#8])-[#8]-[#6]-[#6]-[#8]',
            'sorbitan monooleate': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]=[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6](-[#6]1-[#6](-[#6](-[#6]-[#8]-1)-[#8])-[#8])-[#8]',
            'sorbitan monolaurate': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6](-[#6]1-[#6](-[#6](-[#6]-[#8]-1)-[#8])-[#8])-[#8]',
            'sorbitan monostearate': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6](-[#6]1-[#6](-[#6](-[#6]-[#8]-1)-[#8])-[#8])-[#8]',
            'poloxamer 188': '[#6]-[#6]-[#6]-[#8]-[#6](-[#6])-[#6]-[#8]-[#6]-[#6]-[#8]',
            'poloxamer 407': '[#6]-[#6]1-[#6]-[#8]-1.[#6]1-[#6]-[#8]-1',
            'poe-35-castor oil': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](-[#6]-[#6]=[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#8]-[#6](=[#8])-[#8]-[#6]-[#6]-[#8]-[#6]-[#6](-[#6]-[#8]-[#6]-[#6]-[#8]-[#6](=[#8])-[#8]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]=[#6]-[#6]-[#6](-[#6]-[#6]-[#6]-[#6]-[#6]-[#6])-[#8])-[#8]-[#6]-[#6]-[#8]-[#6](=[#8])-[#8]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]=[#6]-[#6]-[#6](-[#6]-[#6]-[#6]-[#6]-[#6]-[#6])-[#8])-[#8]',
            'peg-660-12-hydroxystearate': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](-[#6])-[#8].[#6H2]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6]-[#8]',
            'tocopheryl-peg 1000-succinate': '[#6]-[#6]1:[#6](:[#6](:[#6](:[#6]2:[#6]:1-[#8]-[#6](-[#6]-[#6]-2)(-[#6])-[#6]-[#6]-[#6]-[#6](-[#6])-[#6]-[#6]-[#6]-[#6](-[#6])-[#6]-[#6]-[#6]-[#6](-[#6])-[#6])-[#6])-[#8]-[#6](=[#8])-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6]-[#8])-[#6]',
            'sucrose laurate': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]1(-[#6](-[#6](-[#6](-[#6](-[#8]-1)-[#6]-[#8])-[#8])-[#8])-[#8])-[#6]1(-[#6](-[#6](-[#6](-[#8]-1)-[#6]-[#8])-[#8])-[#8])-[#6]-[#8]',
            'sucrose palmitate': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]1(-[#6](-[#6](-[#6](-[#6](-[#8]-1)-[#6]-[#8])-[#8])-[#8])-[#8])-[#6]1(-[#6](-[#6](-[#6](-[#8]-1)-[#6]-[#8])-[#8])-[#8])-[#6]-[#8]',
            'caprylyl glucoside': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#8]-[#6]1-[#6](-[#6](-[#6](-[#6](-[#8]-1)-[#6]-[#8])-[#8])-[#8])-[#8]',
            'polyetetramethyl butyl phenol ether': '[#6]-[#6](-[#6])(-[#6])-[#6]-[#6](-[#6])(-[#6])-[#6]1:[#6]:[#6]:[#6](:[#6]:[#6]:1)-[#8]-[#6]-[#6]-[#8]',
            'soybean lecithin': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6](-[#6]-[#8]-[#15](=[#8])(-[#8-])-[#8]-[#6]-[#6]-[#7+](-[#6])(-[#6])-[#6])-[#8]-[#6](=[#8])-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]=[#6]-[#6]-[#6]=[#6]-[#6]-[#6]-[#6]-[#6]-[#6]',
            'egg lecithin': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6](-[#6]-[#8]-[#15](=[#8])(-[#8-])-[#8]-[#6]-[#6]-[#7+](-[#6])(-[#6])-[#6])-[#8]-[#6](=[#8])-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]=[#6]-[#6]-[#6]=[#6]-[#6]-[#6]-[#6]-[#6]-[#6]',
            'diolelyl phosphatidyl choline': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]=[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6](-[#6]-[#8]-[#15](=[#8])(-[#8-])-[#8]-[#6]-[#6]-[#7+](-[#6])(-[#6])-[#6])-[#8]-[#6](=[#8])-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]=[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]',
            'distearoyl phosphatidyl glycerol': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6](-[#6]-[#8]-[#15](=[#8])(-[#8])-[#8]-[#6]-[#6](-[#6]-[#8])-[#8])-[#8]-[#6](=[#8])-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]',
            'dimyristoyl phosphotidyl choline': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6](-[#6]-[#8]-[#15](=[#8])(-[#8-])-[#8]-[#6]-[#6]-[#7+](-[#6])(-[#6])-[#6])-[#8]-[#6](=[#8])-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]',
            'dioctyl sodium sulfosuccinate': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#8]-[#6](=[#8])-[#6]-[#6](-[#6](=[#8])-[#8]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6])-[#16](=[#8])(=[#8])-[#8-].[Na+]',
            'ethanol': '[#6]-[#6]-[#8]',
            'benzyl alcohol': '[#6]1:[#6]:[#6]:[#6](:[#6]:[#6]:1)-[#6]-[#8]',
            'isopropanol': '[#6]-[#6](-[#6])-[#8]',
            'phenethyl alcohol': '[#6]1:[#6]:[#6]:[#6](:[#6]:[#6]:1)-[#6]-[#6]-[#8]',
            'propylene glycol': '[#6]-[#6](-[#6]-[#8])-[#8]',
            'glycerol': '[#6](-[#6](-[#6]-[#8])-[#8])-[#8]',
            'butylene glycol': '[#6]-[#6](-[#6]-[#6]-[#8])-[#8]',
            'peg 400': '[#6]-[#6](-[#6])-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]-[#6]-[#6]-[#8]',
            'transcutol': '[#6]-[#6]-[#8]-[#6]-[#6]-[#8]-[#6]-[#6]-[#8]',
            'tetraglycol': '[#6](-[#6]-[#8]-[#6]-[#6]-[#8]-[#6]-[#6]-[#8]-[#6]-[#6]-[#8])-[#8]',
            'n-methyl pyrrolidone': '[#6]-[#7]1-[#6]-[#6]-[#6]-[#6]-1=[#8]',
            '2-pyrrolidone': '[#6]1-[#6]-[#6](=[#8])-[#7]-[#6]-1',
            'sodium deoxycholate': '[#6]-[#6](-[#6]-[#6]-[#6](=[#8])-[#8-])-[#6]1-[#6]-[#6]-[#6]2-[#6]-1(-[#6](-[#6]-[#6]1-[#6]-2-[#6]-[#6]-[#6]2-[#6]-1(-[#6]-[#6]-[#6](-[#6]-2)-[#8])-[#6])-[#8])-[#6].[Na+]',
            'caprylic acid': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8]',
            'sodium caprylate': '[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6]-[#6](=[#8])-[#8-].[Na+]',
            'potassium sorbate': '[#6]-[#6]=[#6]-[#6]=[#6]-[#6](=[#8])-[#8-].[K+]',
        }


        return smarts